export interface TransformCodeResult {
    state: Record<any, any>;
    lifeCycles: Record<any, any>;
    methods: Record<any, any>;
}
/**
 * AST 分析代码转换 结构化的 json，  此处顺带会将 ts tsx 代码全部转化为 es5
 *
 *
 * example:
 * class LowcodeComponent extends Component {
 *   state = {
 *     "text": "outer",
 *     "isShowDialog": false
 *   }
 *
 *   componentDidMount() {
 *     console.log('did mount');
 *   }
 *
 *   componentWillUnmount() {
 *     console.log('will unmount');
 *   }
 *
 *   testFunc() {
 *     console.log('test func');
 *   }
 *
 *   onClick() {
 *     this.setState({
 *       isShowDialog: true
 *     });
 *   }
 * }
 *
 * 通过结构话化的转换为：
 * {
 *     "state": {
 *         "\"text\"": {
 *             "type": "JSExpression",
 *             "value": "\"odduter\""
 *         },
 *         "\"isShowDialog\"": {
 *             "type": "JSExpression",
 *             "value": "false"
 *         }
 *     },
 *     "lifeCycles": {
 *         "componentDidMount": {
 *             "type": "JSFunction",
 *             "value": "{\n    console.log('did mount');\n}\n"
 *         },
 *         "componentWillUnmount": {
 *             "type": "JSFunction",
 *             "value": "{\n    console.log('will unmount');\n}\n"
 *         }
 *     },
 *     "methods": {
 *         "testFunc": {
 *             "type": "JSFunction",
 *             "value": "{\n    console.log('test func');\n}\n"
 *         },
 *         "onClick": {
 *             "type": "JSFunction",
 *             "value": "{\n    this.setState({\n        isShowDialog: true\n    });\n}\n"
 *         }
 *     }
 * }
 * @param code
 */
export declare function TransformCodeToStructuringJson(code: string): TransformCodeResult;
/**
 * // 假设您已经有组件的 state 和其他必要的数据
 * const componentState = {
 *   isShowDialog: false
 * };
 *
 * // 解析 JSON 对象中的方法
 * const onClickFunction = new Function("state", "return " + json.onClick.value)(componentState);
 *
 * // 在组件中定义一个函数来执行这个方法
 * function handleOnClick() {
 *   onClickFunction.call(this);
 * }
 *
 * // 渲染组件时，将这个函数绑定到相应的事件上
 * <button onClick={handleOnClick}>Click me</button>
 */ 
